from clr import AddReference
from bird import BObject
from bird_telerik import (telerik_wincontrols_win11_lib, telerik_wincontrols_office2013_light_lib,
                          telerik_wincontrols_office2013_dark_lib, telerik_wincontrols_vs2012_light_lib,
                          telerik_wincontrols_vs2012_dark_lib)


class BTWindows11Theme(BObject):
    def Init(self):
        AddReference(telerik_wincontrols_win11_lib)
        from Telerik.WinControls.Themes import Windows11Theme
        self._ = Windows11Theme()

    def __str__(self):
        return "Windows11"


class BTOffice2013Theme(BObject):
    def Init(self):
        AddReference(telerik_wincontrols_office2013_light_lib)
        from Telerik.WinControls.Themes import Office2013LightTheme
        self._ = Office2013LightTheme()

    def __str__(self):
        return "Office2013Light"


class BTOffice2013DarkTheme(BObject):
    def Init(self):
        AddReference(telerik_wincontrols_office2013_dark_lib)
        from Telerik.WinControls.Themes import Office2013DarkTheme
        self._ = Office2013DarkTheme()

    def __str__(self):
        return "Office2013Dark"


class BTVS2012Theme(BObject):
    def Init(self):
        AddReference(telerik_wincontrols_vs2012_light_lib)
        from Telerik.WinControls.Themes import VisualStudio2012LightTheme
        self._ = VisualStudio2012LightTheme()

    def __str__(self):
        return "VisualStudio2012Light"


class BTVS2012DarkTheme(BObject):
    def Init(self):
        AddReference(telerik_wincontrols_vs2012_dark_lib)
        from Telerik.WinControls.Themes import VisualStudio2012DarkTheme
        self._ = VisualStudio2012DarkTheme()

    def __str__(self):
        return "VisualStudio2012Darl"


from bird_telerik.ui.widget import BTWidget
from bird_form.windows.window import BFWindow


class BTWindow(BFWindow, BTWidget):
    def Init(self):
        from Telerik.WinControls.UI import RadForm
        self._ = RadForm()


import os
lib = os.path.dirname(__file__).replace("\\", "//")

telerik_wincontrols_lib = lib + "//ui//Telerik.WinControls.dll"
telerik_wincontrols_ui_lib = lib + "//ui//Telerik.WinControls.UI.dll"

telerik_wincontrols_win11_lib = lib + "//ui//Telerik.WinControls.Themes.Windows11.dll"
telerik_wincontrols_office2013_light_lib = lib + "//ui//Telerik.WinControls.Themes.Office2013Light.dll"
telerik_wincontrols_office2013_dark_lib = lib + "//ui//Telerik.WinControls.Themes.Office2013Dark.dll"
telerik_wincontrols_vs2012_light_lib = lib + "//ui//Telerik.WinControls.Themes.VisualStudio2012Light"
telerik_wincontrols_vs2012_dark_lib = lib + "//ui//Telerik.WinControls.Themes.VisualStudio2012Dark"

from bird_telerik.ui import *



from bird_form.windows.widget import BFWidget


class BTTaskBarButton(BFWidget):
    def Init(self):
        from Telerik.WinControls.UI import RadTaskbarButton
        self._ = RadTaskbarButton()

    def Add(self, Button):
        self._.ThumbnailButtons.Add(Button.Get())

    def OwnerWindow(self, Window):
        self._.OwnerForm = Window.Get()


from clr import AddReference
from bird_telerik import telerik_wincontrols_ui_lib

AddReference(telerik_wincontrols_ui_lib)

from bird_telerik.ui.widget import BTWidget
from bird_telerik.ui.window import BTWindow
from bird_telerik.ui.themes import (BTWindows11Theme, BTVS2012Theme, BTVS2012DarkTheme,
                                    BTOffice2013Theme, BTOffice2013DarkTheme)
from bird_telerik.ui.button import BTButton

from bird_telerik.ui.taskbarbutton import BTTaskBarButton
from bird_telerik.ui.thumbnailbutton import BTThumbnailButton


from setuptools import find_packages, setup

setup(
    name="bird-dev-form-telerik",
    version="1.0.0a1",
    author="XiangQinxi",
    author_email="XiangQinxi@outlook.com",
    description="Bird Dev",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    python_requires=">=3",
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests"]),
    package_data={"": ["*", "*.dll"]},
    requires=[],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



from bird_form.windows.button import BFButton
from bird_telerik.ui.widget import BTWidget


class BTButton(BFButton, BTWidget):
    def Init(self):
        from Telerik.WinControls.UI import RadButton
        self._ = RadButton()